==> hobson-0.8.10.tgz: package/lib/attach.js <==
'use strict';

var express = require('express');
var HTTPStatus = require('http-status');
var errors = require('./errors');
var TokenSchema = require('./token/schema');

var _require = require('./utils/helpers'),
    formatResponse = _require.formatResponse,
    expect = _require.expect;

var _require2 = require('./utils/auth'),
    authPopulate = _require2.authPopulate,
    tokenPopulate = _require2.tokenPopulate;

var UserResource = require('./user/resource');

/**
 * Parse the body of the requests.
 */
function parseRequestBody(app) {
  app.use(express.json());
  app.use(express.urlencoded({ extended: true }));
}

/**
 * Catch any requests or errors which aren't in the api.
 */
function handleErrors(app, debug) {
  return app.use(function (req, res, next) {
    var error = new errors.Response({
      message: 'Request address does not exist on the api.',
      status: HTTPStatus.NOT_FOUND
    });
    next(error);
  }).use(function (err, req, res, next) {
    res.status(err.status || HTTPStatus.INTERNAL_SERVER_ERROR).json(formatResponse(err, debug));
    next();
  });
}

/**
 * Add a health check route.
 */
function environmentCheck(app) {
  var response = formatResponse({
    data: {
      environment: process.env.NODE_ENV
    }
  });
  app.get('/', function (req, res) {
    res.status(response.status || HTTPStatus.INTERNAL_SERVER_ERROR).json(response);
  });
}

/**
 * Attach multiple resources to a single app instance and provide authentication.
 *
 * @param {function} app the express app instance.
 * @param {array} resources an array of the hobson resources to attach to the app.
 * @param {string} secret a unique, random secret string used in authenticating users and tokens.
 * @param {boolean} status this will add a index route which returns the app environment.
 * @param {boolean} debug determines if the app should return stack traces in errors.
 * @param {string} token the token model name if not 'Token' as per default.
 * @param {function} before a function used to configure the app before attaching resources (not recommended to change).
 * @param {function} after a function used to configure the app after attaching resources.
 */
module.exports = function attach(_ref) {
  var app = _ref.app,
      resources = _ref.resources,
      secret = _ref.secret,
      _ref$status = _ref.status,
      status = _ref$status === undefined ? true : _ref$status,
      _ref$debug = _ref.debug,
      debug = _ref$debug === undefined ? false : _ref$debug,
      _ref$token = _ref.token,
      token = _ref$token === undefined ? 'Token' : _ref$token,
      before = _ref.before,
      after = _ref.after;

  if (typeof app !== 'function' || typeof app.use !== 'function') {
    throw new errors.Response({ message: 'Parameter "app" must be an express app instance.' });
  }
  if (!resources || !Array.isArray(resources)) {
    throw new errors.Response({ message: 'Parameter "resources" must be an array of resources.' });
  }
  if (typeof secret !== 'string') {
    throw new errors.Response({ message: 'Parameter "secret" must be a random string used to authenticate requests.' });
  }
  expect({ name: 'status', value: status, type: 'boolean' });
  expect({ name: 'debug', value: debug, type: 'boolean' });
  expect({ name: 'token', value: token, type: 'string' });
  expect({ name: 'before', value: before, type: 'function', optional: true });
  expect({ name: 'after', value: after, type: 'function', optional: true });
  if (before) {
    before(app);
  } else {
    parseRequestBody(app);
  }
  var tokenSchema = new TokenSchema();
  var Token = tokenSchema.compile(token);
  app.use(tokenPopulate({ Token: Token, secret: secret }));
  var userResource = resources.find(function (resource) {
    return resource instanceof UserResource;
  });
  if (userResource) {
    app.use(authPopulate({ User: userResource.model, secret: secret }));
    userResource.option({ Token: Token, secret: secret });
  }
  resources.forEach(function (resource) {
    return resource.attach(app);
  });
  if (status) {
    environmentCheck(app);
  }
  if (after) {
    after(app);
  }
  handleErrors(app, debug);
};

==> hobson-0.9.1.tgz: package/lib/attach.js <==
'use strict';

var express = require('express');
var HTTPStatus = require('http-status');
var errors = require('./errors');

var _require = require('./utils/helpers'),
    formatResponse = _require.formatResponse,
    expect = _require.expect,
    depreciated = _require.depreciated;

var _require2 = require('./utils/auth'),
    authPopulate = _require2.authPopulate,
    tokenPopulate = _require2.tokenPopulate;

var UserResource = require('./user/resource');

/**
 * Parse the body of the requests.
 */
function parseRequestBody(app) {
  app.use(express.json());
  app.use(express.urlencoded({ extended: true }));
}

/**
 * Catch any requests or errors which aren't in the api.
 */
function handleErrors(app, debug) {
  return app.use(function (req, res, next) {
    var error = new errors.NotFoundResponse({ message: 'Request address does not exist on the api.' });
    next(error);
  }).use(function (err, req, res, next) {
    res.status(err.status || HTTPStatus.INTERNAL_SERVER_ERROR).json(formatResponse(err, debug));
    next();
  });
}

/**
 * Add a health check route.
 */
function environmentCheck(app) {
  var response = formatResponse({
    data: {
      environment: process.env.NODE_ENV
    }
  });
  app.get('/', function (req, res) {
    res.status(response.status || HTTPStatus.INTERNAL_SERVER_ERROR).json(response);
  });
}

/**
 * Attach multiple resources to a single app instance and provide authentication.
 *
 * @param {function} app the express app instance.
 * @param {array} resources an array of the hobson resources to attach to the app.
 * @param {string} secret a unique, random secret string used in authenticating users and tokens.
 * @param {boolean} status this will add a index route which returns the app environment.
 * @param {boolean} debug determines if the app should return stack traces in errors.
 * @param {function} before a function used to configure the app before attaching resources (not recommended to change).
 * @param {function} after a function used to configure the app after attaching resources.
 */
module.exports = function attach(_ref) {
  var app = _ref.app,
      resources = _ref.resources,
      secret = _ref.secret,
      _ref$status = _ref.status,
      status = _ref$status === undefined ? true : _ref$status,
      _ref$debug = _ref.debug,
      debug = _ref$debug === undefined ? false : _ref$debug,
      before = _ref.before,
      after = _ref.after,
      token = _ref.token;

  if (typeof app !== 'function' || typeof app.use !== 'function') {
    throw new errors.BreakingResponse({ message: 'Parameter "app" must be an express app instance.' });
  }
  if (!resources || !Array.isArray(resources)) {
    throw new errors.BreakingResponse({ message: 'Parameter "resources" must be an array of resources.' });
  }
  if (typeof secret !== 'string') {
    throw new errors.BreakingResponse({ message: 'Parameter "secret" must be a random string used to authenticate requests.' });
  }
  depreciated({ name: 'token', value: token });
  expect({ name: 'status', value: status, type: 'boolean' });
  expect({ name: 'debug', value: debug, type: 'boolean' });
  expect({ name: 'before', value: before, type: 'function', optional: true });
  expect({ name: 'after', value: after, type: 'function', optional: true });
  if (before) {
    before(app);
  } else {
    parseRequestBody(app);
  }
  app.use(tokenPopulate({ secret: secret }));
  resources.filter(function (source) {
    return source instanceof UserResource;
  }).forEach(function (source) {
    app.use(authPopulate({ User: source.model, secret: secret }));
    source.option({ secret: secret });
  });
  resources.forEach(function (resource) {
    return resource.attach(app);
  });
  if (status) {
    environmentCheck(app);
  }
  if (after) {
    after(app);
  }
  handleErrors(app, debug);
};
